@@ -2,8 +2,9 @@ from dagster.core.utils import check_dagster_package_version
 
 from .context import DagstermillExecutionContext
 from .errors import DagstermillError
+from .factory import define_dagstermill_op, define_dagstermill_solid
+from .io_managers import local_output_notebook_io_manager
 from .manager import MANAGER_FOR_NOTEBOOK_INSTANCE as _MANAGER_FOR_NOTEBOOK_INSTANCE
-from .solids import define_dagstermill_solid
 from .version import __version__
 
 check_dagster_package_version("dagstermill", __version__)
@@ -18,6 +19,4 @@ _reconstitute_pipeline_context = _MANAGER_FOR_NOTEBOOK_INSTANCE.reconstitute_pip
 
 _teardown = _MANAGER_FOR_NOTEBOOK_INSTANCE.teardown_resources
 
-_load_parameter = _MANAGER_FOR_NOTEBOOK_INSTANCE.load_parameter
-
 _load_input_parameter = _MANAGER_FOR_NOTEBOOK_INSTANCE.load_input_parameter
